@@ -803,6 +803,10 @@ struct ext2_super_block {
 
 #define EXT2_GOOD_OLD_INODE_SIZE 128
 
+#define EXT4_EXTRA_TIMESTAMP_MAX	(((int64_t)1 << 34) - 1  + INT32_MIN)
+#define EXT4_NON_EXTRA_TIMESTAMP_MAX	INT32_MAX
+#define EXT4_TIMESTAMP_MIN		INT32_MIN
+
 /*
  * Journal inode backup types
  */
@@ -1124,8 +1128,8 @@ static inline unsigned int ext2fs_dir_rec_len(__u8 name_len,
 
 /* Structure at the tail of orphan block */
 struct ext4_orphan_block_tail {
-	__u32 ob_magic;
-	__u32 ob_checksum;
+	__le32 ob_magic;
+	__le32 ob_checksum;
 };
 
 /*
